
clear all
capture log close
set mem 500m
vers 11
set mem 1500m
set maxvar 30000
set matsize 11000

/*-------------------------------------------------------------
This program generates the results for child health
in table 5, and generates a placebo test for
anemia. It calls the mother and child DHS survey data,
as well as location identifiers. It also constructs p-values
for anemia based on permutation-based placebo test. The placebo test will need
a file that has been generated by chiefs_analysis_placebo.do

Last Edit: TR, 5/7/2013
---------------------------------------------------------------*/
  
log using $SL_log/chiefs_table5_rr.log, replace

loc exocontrol mitchell_km coast_dist river_dist rail_dist dist_min mining_1930

/*-----------------------
1. Getting DHS Locations
------------------------*/
  
insheet using $SL_data/chiefs_dhs_locations.txt

keep code dhsclust
rename code chiefcode
sort dhsclust

save $SL_data/chiefs_dhs_locations.dta, replace

/*----------------------------------
2. Getting Mother Information
-----------------------------------*/
use $SL_data/dhs_indiv_SLIR51FL.dta, clear

gen age = v012
gen age2 = age^2
replace v131 = . if v131==99
gen ethnicity = v131
tab ethnicity, gen(eth_)
drop eth_3 eth_9 eth_10
gen primary = v106 > 0

keep v001 v002 v003 eth* age* primary

sort v001 v002 v003
tempfile mothers
save `mothers'

/*------------------------------
3. Getting Child Information
------------------------------*/

use $SL_data/dhs_child_Slkr51fl.dta

sort v001 v002 v003
merge m:1 v001 v002 v003 using `mothers'
rename _merge  _mothers

*Height and Weight Statistics
gen height_age_who = hw70/100
gen weight_age_who = hw71/100
gen weight_height_who = hw72/100
gen bmi_who = hw73/100

/*Dropping Implausibly Large Outliers*/
replace bmi_who = . if abs(bmi)>5
replace weight_height_who = . if abs(weight_height_who)>5

*Dummy for Moderate to Severe Anemia
gen anemia = (hw57 == 1 | hw57==2)
replace anemia = . if hw57==9 | hw57 == . 

/*-----------------------
4. Merging Chiefs Data
------------------------*/
rename v001 dhsclust

sort dhsclust
merge m:1 dhsclust using $SL_data/chiefs_dhs_locations.dta
rename _merge _m_locations
tab chiefcode

lab val chiefcode chief_codes

merge m:1 chiefcode using $SL_data/chiefs_survey_clean_out.dta

list district chiefcode fam_num if _merge==2
keep if _merge==3
drop _merge

lab var amalgamation "Amalgamation"
lab var n_chiefs "Number of chiefs recalled"

compress
save $SL_temp/chiefs_dhs.dta, replace

/*-----------------------
5. Regressions
------------------------*/

loc run = 1
if `run' == 1{
  
loc study_controls amalgamation n_chiefs 
loc district_fe dist? dist??
loc mother_controls age age2 eth_*
loc dec = 3

/*Summary Stats for Table 1*/
foreach y in weight_height_who anemia bmi_who {
  sum `y' if missing(fam_cat) ==0 
  tabstat `y' [fw = round(v005) ], by(fam_cat) stat(mean sd)
}

foreach var of varlist weight_height_who bmi_who anemia { 

/*Fixing for Outreg*/
if "`var'" == "weight_height_who"{
  loc rcond replace
}
else{
  loc rcond
}

/*--------------------------
1.Without Mother Controls
--------------------------*/

/*Without Historical controls*/
regress `var' fam_num_ln  `study_controls' `district_fe' [pw = v005] , cluster( chiefcode) 

 outreg2 using "$SL_out/chiefs_table5.tex", `rcond'  tex(frag) drop(`exocontrol'  `mother_controls' `district_fe' ) dec(`dec') ctitle("`y'") addtext( Mother Controls , NO , District Fixed Effects, YES, Historical Controls,NO  ) addstat(Number of Chiefdoms, e(N_clust) ) noaster nonotes nocons label 

/*With Historical controls*/
regress `var' fam_num_ln  `study_controls' `district_fe' `exocontrol' [pw = v005] , cluster( chiefcode) 

 outreg2 using "$SL_out/chiefs_table5_exocontrol.tex", `rcond'  tex(frag) drop(`exocontrol'  `mother_controls' `district_fe' ) dec(`dec') ctitle("`y'") addtext( Mother Controls , NO , District Fixed Effects, YES, Historical Controls, YES  ) addstat(Number of Chiefdoms, e(N_clust) ) noaster nonotes nocons label 

/*---------------------------
2. With Mother Controls
---------------------------*/

/*With historical controls*/  
 regress `var' fam_num_ln `mother_controls' `study_controls' `district_fe' [pw = v005] , cluster( chiefcode) 

outreg2 using "$SL_out/chiefs_table5.tex", tex(frag) drop( `exocontrol'  `mother_controls'  `district_fe' ) dec(`dec') ctitle("`y'") addtext( Mother Controls , YES , District Fixed Effects, YES, Historical Controls, NO ) addstat(Number of Chiefdoms, e(N_clust)) noaster nonotes nocons label

/*Without historical controls*/  
 regress `var' fam_num_ln `mother_controls' `study_controls' `district_fe' `exocontrol' [pw = v005] , cluster( chiefcode) 

outreg2 using "$SL_out/chiefs_table5_exocontrol.tex", tex(frag) drop( `exocontrol'  `mother_controls'  `district_fe' ) dec(`dec') ctitle("`y'") addtext( Mother Controls , YES , District Fixed Effects, YES, Historical Controls, YES   ) addstat(Number of Chiefdoms, e(N_clust)) noaster nonotes nocons label

/*--------------------------------------
3. Researcher Fixed effect appendix with Mother Controls (no historical contols)
---------------------------------------------*/

regress `var' fam_num_ln `mother_controls' `study_controls' `district_fe'  research_dummy* [pw = v005] , cluster( chiefcode) 

outreg2 using "$SL_out/chiefs_table5_researcher.tex", `rcond' tex(frag) drop(  `mother_controls'  `district_fe' ) dec(`dec') ctitle("`y'") addtext( Mother Controls , YES , District Fixed Effects, YES, Researcher Fixed Effects, YES ) addstat(Number of Chiefdoms, e(N_clust)) noaster nonotes nocons label

}

}

/*-------------------------------------------
Placebo Effects

Need to run "chiefs_analysis_placebo.do" first here to get simulated number
of families, and set number of straps correctly below.
--------------------------------------------*/

loc straps = 1000

loc study_controls n_chiefs amalgamation
loc district_fe dist? dist??
loc mother_controls age age2 eth_*

loc run = 0
if `run' == 1{
  
/*Bringing in Placebos*/
merge m:1 chiefcode using $SL_data/chiefs_analysis_placebo.dta
drop _merge
     
compare fam_num_ln fam_num_ln_0

lab var anemia "Prevalence of severe or moderate anemia under age 5"

/*Looping over Outcomes of Interest*/
foreach y of varlist anemia  {

local title: variable label `y'
  
/*Original Regression*/
reg `y' fam_num_ln `mother_controls' `study_controls' `district_fe'  [pw = v005] 

loc b0_`y' = round(_b[fam_num_ln],0.001)

/*Preparing Empty Matrix to Store Coefficients from Placebo Model*/
matrix b`y' = J(`straps',1,.)

/*Running Placebo Regressions*/
foreach k of numlist 1/`straps' {
    qui reg `y' fam_num_ln_`k' `mother_controls' `study_controls' `district_fe'  [pw = v005] 
    matrix b`y'[`k',1] = _b[fam_num_ln_`k']
}

/*Outputting Placebo Coefficients*/
preserve

clear
svmat b`y', names(col)
rename c1 b`y'_placebo
gen b`y'_true = `b0_`y''

/*1. Summarizing*/
di "Distribution of placebo effects on `y'"
sum b`y'_placebo, d
di "True effect: `b0_`y''"

/*2. Getting Number of times effect is less than placebo*/
gen lessthan = (b`y'_true > b`y'_placebo)
label var lessthan "Percent of times placebo is less than treatment"
sum lessthan
loc lessthan_pc = 100*round(r(mean),0.001)

gen greaterthan = (b`y'_true < b`y'_placebo)
label var greaterthan "Percent of times placebo is greater than treatment"
sum greaterthan
loc greaterthan_pc = 100*round(r(mean),0.001)

/*3. Density Plot*/
loc bins = `straps'/20
  
histogram b`y'_placebo, xline(`b0_`y'', lpattern(dash) ) percent xtitle("Placebo effects of log number of ruling families") note( "Dashed line indicates true estimate of `b0_`y'' in DHS sample; `lessthan_pc'% of placebo effects are less." "Placebos generated `straps' times." ) title("`title'") bin(`bins') scheme(sj)

graph save $SL_graph/placebo_less_`y', replace

histogram b`y'_placebo, xline(`b0_`y'', lpattern(dash) ) percent xtitle("Placebo effects of log number of ruling families") note( "Dashed line indicates true estimate of `b0_`y'' in DHS sample; `greaterthan_pc'% of placebo effects are greater." "Placebos generated `straps' times.") title("`title'") bin(`bins') scheme(sj)

graph save $SL_graph/placebo_greater_`y', replace

/*4. Saving Out*/
save $SL_out/placebo_`y'.dta, replace

restore

}
}
